#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_DEVGTK
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_LIBSM
#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
#undef HAVE_PROGRAM_INVOCATION_NAME

#undef GNOMECC_DATA_DIR

#undef PACKAGE
#undef VERSION

#undef HAVE_ESD
#undef HAVE_LIBESD

/* Define if there is no `u_int64_t' and `int64_t'. */
#undef u_int64_t
#undef int64_t

#undef HAVE_DEVGTK

#undef WITH_SYMBOL_UNDERSCORE

#undef HAVE_PUTENV
#undef HAVE_SETENV
